==> Morpho-0.2.B2.tar.gz: Morpho-0.2.B2/src/jp/morpho/webapp/action/ActionHandler.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.action;

import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * <P>
 * ActionHandler 󥿥եϡƥϥɥ饯饹ˤäƼޤ
 * ϥɥϡ饤Ȥ׵ФǤդν¹Ԥ륪֥ȤǤ
 * </P>
 * <P>
 * ActionHandler ϡdoActionHandler ᥽åɤˤƥץꥱå¹Ԥޤ
 * ٤Ƥ ActionHandler  HttpActionRequest ֥ȤإǤΥ֥Ȥɬפʥ꥽Υɤʤɤ˻ѤǤ FrameworkContext ؤλȤ뤳ȤǤޤ
 * </P>
 * @author Kenichi Fukuda
 */
public interface ActionHandler
{
//------------------------------------------------------------------------------
//᥽å
//------------------------------------------------------------------------------
	/**
	 * <P>
	 * ActionHandler  doActionHandler ᥽åɤϡνüˤ꥽򥯥饤Ȥ׵᤹뤳Ȥ򤭤äȤơ׵ȱΥڥݥ˱äϤƤȤˡActionHandlerChain ˸ƤӽФޤ
	 * Υ᥽åɤϤ ActionHandlerChain ˤäơActionHandler ׵ȱݥμΥƥƥϤȤǤޤ
	 * </P>
	 * @param request ˱äϤ׵
	 * @param response ˱äϤ
	 * @param chain ¹ ActionHandler ޤॢϥɥ
	 * @exception ActionHandlerException ϥɥ̾ν˸㳰ȯ
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException;

}

==> Morpho-1.0.B2.tar.gz: Morpho-1.0.B2/src/jp/morpho/webapp/action/ActionHandler.java <==
/*
 * Copyright (c) 2003, Morpho Project.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *	  this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *	  this list of conditions and the following disclaimer in the documentation
 *	  and/or other materials provided with the distribution.
 * 3. Neither the name of the Morpho Project nor the names of its contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package jp.morpho.webapp.action;

import jp.morpho.webapp.servlet.http.HttpActionRequest;
import jp.morpho.webapp.servlet.http.HttpActionResponse;

/**
 * <P>
 * ActionHandler C^tF[X́AeANVnhNXɂĎ܂B
 * ANVnh́ANCAg̗vɑ΂ĔCӂ̏sIuWFNgłB
 * </P>
 * <P>
 * ActionHandler ́AdoActionHandler \bhɂăAvP[VWbNs܂B
 * ׂĂ ActionHandler  HttpActionRequest IuWFNgփANZXłÃIuWFNgKvȃ\[X̃[hȂǂɎgpł FrameworkContext ւ̎QƂ擾邱Ƃł܂B
 * </P>
 * @author Kenichi Fukuda
 */
public interface ActionHandler
{
//------------------------------------------------------------------------------
//\bh
//------------------------------------------------------------------------------
	/**
	 * <P>
	 * ActionHandler  doActionHandler \bh́A`F[̏I[ɂ郊\[XNCAgv邱ƂƂāAvƉ̃yA`F|ɉēnĂƂɁAActionHandlerChain ɌĂяo܂B
	 * ̃\bh֓n ActionHandlerChain ɂāAActionHandler ͗vƉ`F|̎̃GeBeBɓnƂł܂B
	 * </P>
	 * @param request `F[ɉēnv
	 * @param response `F[ɉēn
	 * @param chain s ActionHandler ܂ރANVnh`FC
	 * @exception ActionHandlerException ANVnh̒ʏ̏WOꍇ
	 */
	public void doActionHandler(
		HttpActionRequest request,
		HttpActionResponse response,
		ActionHandlerChain chain)
		throws ActionHandlerException;

}
